@@ -14,6 +14,15 @@ from .impala_utils import ImpalaUtils
 
 
 def datadownload(user_sql, conn_type='impala'):
+    """ Download data from Hive or Impala platforms.
+
+    Args:
+        user_sql (str): SQL
+        conn_type (str): 'hive' or 'impala'
+
+    Returns:
+        a Pandas DataFrame object
+    """
     handler = ImpalaUtils(conn_type=conn_type)
     # USER_QUERY_SQL = open(sqlfile,'r',encoding='utf8').read()
     # user_sql = user_sql.replace('2019-01-01',ds)
